; Small AutoHotkey script to use the arrow keys, letters and numbers in the Perseus receiver software (by Nico Palermo)
; Modified version with special commands to perform ShuttleProV2 USB Human interface
;**************************************************************************************************************
; Help:

; Right arrow 			=> Equ. to the mouseWheel down
; Left arrow  			=> Equ. to the mouseWheel up
; Shift + Right arrow 		=> Equ. to 10 notches of the mouseWheel down
; Shift + Left arrow  		=> Equ. to 10 notches of the mouseWheel up
; Down arrow 			=> Decrease span (wider traces on the waterfall)
; Up arrow   			=> Increase span (narrower traces on the waterfall)
; PageDown 			=> Decrease "wheel step"
; PageUp   			=> Increase "wheel step"
; < 				=> Decrease "CF STEP"
; > 				=> Increase "CF STEP"
; / 				=> Decrease "Ref Lev (dBm)"
; * 				=> Increase "Ref Lev (dBm)"
; Enter 			=> Opens the "Frequency (KHz) dialog  for input, then close the keypad (with another Enter)
; 1, 2, 3, 4, 5, 6, 7, 8, 9, 0	=> Open the freq dialog, send this number, add the others and close (with Enter)
; a, s, c, r, l, u, f, d, e    	=> Activate Modes: AM, SAM, CW, RTTY, LSB, USB, FM, DRM, user
; +, - (from Numpad) 		=> Activate "USB" and "LSB" (as "u" and "l", but more quickly)
; - 				=> Tuning up fm value of CF Step
; _ 				=> Tuning up fm value of CF Step
; w 				=> switch to waterfall
; t 				=> switch to spectrum
; x 				=> Center frequency in spectrum or waterfall
; o 				=> Toggle Zoom the frequency in waterfall
; b 				=> Toggle Noise Blanker ON/OFF
; n 				=> Toggle Noise Reducer ON/OFF
; j 				=> Toggle "SpkRej" on off
; h 				=> Activate Notch (to deactivate use "y" PBT)
; y 				=> Activate PBT (to deactivate use "h" Notch and so on)
; g 				=> Activate Autonotch
; m 				=> 1. Mute or Activate Volume
; m 				=> 2. after a frequencies input it means "MHz" and close the frequency input window
; k 				=> 1. CWPeak
; k 				=> 2. after a frequencies input it means "kHz" and close the frequency input window
; z 				=> Wave Files change
; Shift q, ALT-F4 		=> Close Perseus and also the script

; (C) Laurent Haas - F6FVY - Nov 2008 (f6fvy _at_ free.fr)
; modified by Aldo Moroni (IW2DZX) and Salvo Micciche' (SWL IT9-4639)
; modified by WoodBoxRadio (IK3VIG)
; Thanks to Wolfgang OE1MWW for some tips
;
; Version 2.5 - Mar 25 2009
; tested with Perseus 2.1f
; Basis for ShuttlePro2 perseus.pref file as edited by SSB Electronic June 11, 2009
;**************************************************************************************************************

#NoEnv          ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.

; don't remove the above line: it try to avoid to run the script with another window called "Perseus" 
; that's not the Perseus receiver software
SetTitleMatchMode RegEx

;function for "Frequency" window
sendToFreqWnd(key)
{
  Click,,100,245,2
  WinWait,ahk_class#32770
  ControlFocus,Edit1,ahk_class#32770
  ControlClick,Edit1,ahk_class#32770,LEFT
  IfWinNotActive,ahk_class#32770
    WinActivate
  Click,,110,45
  Send %key%
  return
}

; Activate Perseus if it isn't already active (with "realtime" priority)
IfWinExist Perseus ahk_classAfx:400000:2028:
{
  WinActivate
}
else
{
   Run Perseus,,UseErrorLevel,NewPID
   if ErrorLevel = ERROR
   {
        MsgBox Can't find the Perseus program.`n`nCheck PerseusKeyboard and the Perseus software`nare located in the same directory.
        ExitApp
   }
   Process,Priority,%NewPID%,Realtime
   WinWait Perseus ahk_classAfx:400000:2028:
   WinActivate
}

#IfWinActive Perseus ahk_classAfx:400000:2028:
{

Left::
Click,WU,587,290
return

+Left::
Loop 10
{
  Click,WU,587,290
  Sleep 1
}
return

Right::
Click,WD,587,290
return

+Right::
Loop 10
{
  Click,WD,587,290
  Sleep 1
}
return

Down::
Click,,135,295
return

Up::
Click,,150,295
return

PgUp::
Click,,157,376
return

PgDn::
Click,,132,376
return

<::
Click,,192,309
return

>::
Click,,987,308
return

-::
Click,,130,333
return

_::
Click,,155,334
return

/::
NumpadDiv::
Click,ARROWD,133,152
return

*::
NumpadMult::
Click,ARROWU,157,152
return

t::
+t::
Click,,227,309
return

w::
+w::
Click,,263,309
return

b::
+b::
Click,,518,403
return

n::
+n::
Click,,969,402
return

;Activate keypad
;the "Frequency (KHz) window should stay on its normal position to work better
;there are two Enter (see the last function and don't remove)
Enter::
NumpadEnter::
sendToFreqWnd("{Space}{BS}")
return

0::
Numpad0::
sendToFreqWnd("0")
return

1::
Numpad1::
sendToFreqWnd("1")
return

2::
Numpad2::
sendToFreqWnd("2")
return

3::
Numpad3::
sendToFreqWnd("3")
return

4::
Numpad4::
sendToFreqWnd("4")
return

5::
Numpad5::
sendToFreqWnd("5")
return

6::
Numpad6::
sendToFreqWnd("6")
return

7::
Numpad7::
sendToFreqWnd("7")
return

8::
Numpad8::
sendToFreqWnd("8")
return

9::
Numpad9::
sendToFreqWnd("9")
return

;LSB
l::
+L::
NumPadSub::
Click,,408,353
return

;USB
u::
+U::
NumPadAdd::
Click,,455,353
return

;AM
a::
+A::
Click,,204,353
return

;SAM
s::
+S::
Click,,259,353
return

;CW
+c::
C::
Click,,310,353
return

;RTTY
r::
+R::
Click,,362,353
return

;FM
f::
+F::
Click,,508,353
return

;DRM
d::
+D::
Click,,561,353
return

;User
e::
+E::
Click,,594,353
return

;SpkRej
j::
+j::
Click,,562,458
return

;PBT
y::
+y::
Click,,260,546
return

;Notch
h::
+h::
Click,,300,546
return

;Autonotch
g::
+g::
Click,,340,546
return

;CWPeak
k::
+k::
Click,,380,546
return

;Mute or Activate Volume
m::
+m::
Click,,1002,405
return

;Center frequency
x::
+x::
Click,,23,422
return

;Zoom frequency
o::
+o::
Click,,300,310
Click,,640,45
return

;Wave file change (if it's a single file it works as "rewind")
z::
+z::
click,,1010,603
return

;Close Perseus and the script
+q::
!F4::
Click,,1010,12
ExitApp
return

; Automatically Close keypad after freq input
;please, keep these lines at the end
#IfWinActive ahk_class#32770
; for frequencies in kHz
Enter::
NumpadEnter::
click,,64,184
click,,104,186
return

; for frequencies in MHz
m::
+m::
click,,33,183
click,,104,186
return

; for frequencies in MHz
k::
+k::
click,,63,183
click,,104,186
return
}